==> nextcloud-25.0.11.tgz: nextcloud/apps/systemtags/l10n/ca.js <==
OC.L10N.register(
    "systemtags",
    {
    "Tag name is empty" : "El nom de l'etiqueta és buit",
    "Update" : "Actualitza",
    "Create" : "Crea",
    "Select tag …" : "Seleccioneu una etiqueta…",
    "System tag %1$s added by the system" : "El sistema ha afegit l'etiqueta del sistema %1$s",
    "Added system tag {systemtag}" : "S'ha afegit l'etiqueta del sistema {systemtag}",
    "Added system tag %1$s" : "S'ha afegit l'etiqueta del sistema %1$s",
    "%1$s added system tag %2$s" : "%1$s ha afegit l'etiqueta del sistema %2$s",
    "{actor} added system tag {systemtag}" : "{actor} ha afegit l'etiqueta del sistema {systemtag}",
    "System tag %1$s removed by the system" : "El sistema ha suprimit l'etiqueta del sistema %1$s",
    "Removed system tag {systemtag}" : "S'ha suprimit l'etiqueta del sistema {systemtag}",
    "Removed system tag %1$s" : "S'ha suprimit l'etiqueta del sistema %1$s",
    "%1$s removed system tag %2$s" : "%1$s ha suprimit l'etiqueta del sistema %2$s",
    "{actor} removed system tag {systemtag}" : "{actor} ha suprimit l'etiqueta del sistema {systemtag}",
    "You created system tag %1$s" : "Heu creat l'etiqueta del sistema %1$s",
    "You created system tag {systemtag}" : "Heu creat l'etiqueta del sistema {systemtag}",
    "%1$s created system tag %2$s" : "%1$s ha creat l'etiqueta del sistema %2$s",
    "{actor} created system tag {systemtag}" : "{actor} ha creat l'etiqueta del sistema {systemtag}",
    "You deleted system tag %1$s" : "Heu suprimit l'etiqueta del sistema %1$s",
    "You deleted system tag {systemtag}" : "Heu suprimit l'etiqueta del sistema {systemtag}",
    "%1$s deleted system tag %2$s" : "%1$s ha suprimit l'etiqueta del sistema %2$s",
    "{actor} deleted system tag {systemtag}" : "{actor} ha suprimit l'etiqueta del sistema {systemtag}",
    "You updated system tag %2$s to %1$s" : "Heu actualitzat l'etiqueta del sistema %2$s a %1$s",
    "You updated system tag {oldsystemtag} to {newsystemtag}" : "Heu actualitzat l'etiqueta del sistema {oldsystemtag} a {newsystemtag}",
    "%1$s updated system tag %3$s to %2$s" : "%1$s ha actualitzat l'etiqueta del sistema %3$s a %2$s",
    "{actor} updated system tag {oldsystemtag} to {newsystemtag}" : "{actor} ha actualitzat l'etiqueta del sistema {oldsystemtag} a {newsystemtag}",
    "System tag %2$s was added to %1$s by the system" : "El sistema ha afegit l'etiqueta del sistema %2$s a %1$s",
    "System tag {systemtag} was added to {file} by the system" : "El sistema ha afegit l'etiqueta del sistema {systemtag} a {file}",
    "You added system tag %2$s to %1$s" : "Heu afegit l'etiqueta del sistema %2$s a %1$s",
    "You added system tag {systemtag} to {file}" : "Heu afegit l'etiqueta del sistema {systemtag} a {file}",
    "%1$s added system tag %3$s to %2$s" : "%1$s ha afegit l'etiqueta del sistema %3$s a %2$s",
    "{actor} added system tag {systemtag} to {file}" : "{actor} ha afegit l'etiqueta del sistema {systemtag} a {file}",
    "System tag %2$s was removed from %1$s by the system" : "El sistema ha suprimit l'etiqueta del sistema %2$s de %1$s",
    "System tag {systemtag} was removed from {file} by the system" : "El sistema ha suprimit l'etiqueta del sistema {systemtag} de {file}",
    "You removed system tag %2$s from %1$s" : "Heu suprimit l'etiqueta del sistema %2$s de %1$s",
    "You removed system tag {systemtag} from {file}" : "Heu suprimit l'etiqueta del sistema {systemtag} de {file}",
    "%1$s removed system tag %3$s from %2$s" : "%1$s ha suprimit l'etiqueta del sistema %3$s de %2$s",
    "{actor} removed system tag {systemtag} from {file}" : "{actor} ha suprimit l'etiqueta del sistema {systemtag} de {file}",
    "%s (restricted)" : "%s (restringit)",
    "%s (invisible)" : "%s (invisible)",
    "<strong>System tags</strong> for a file have been modified" : "S'han modificat les <strong>etiquetes del sistema</strong> d'un fitxer",
    "Tags" : "Etiquetes",
    "All tagged %s …" : "Tots els elements amb l'etiqueta %s…",
    "tagged %s" : "amb l'etiqueta %s",
    "Collaborative tags" : "Etiquetes col·laboratives",
    "Collaborative tagging functionality which shares tags among users." : "Funcionalitat d'etiquetatge col·laboratiu que permet compartir etiquetes entre usuaris.",
    "Collaborative tagging functionality which shares tags among users. Great for teams.\n\t(If you are a provider with a multi-tenancy installation, it is advised to deactivate this app as tags are shared.)" : "Funcionalitat d'etiquetatge col·laboratiu que permet compartir etiquetes entre usuaris. Fantàstica per a equips.\n\t(Si sou un proveïdor amb una instància del Nextcloud per a diversos clients, s'aconsella inhabilitar aquesta aplicació perquè les etiquetes es comparteixen amb tothom.)",
    "Loading collaborative tags …" : "S'estan carregant les etiquetes col·laboratives…",
    "Search or create collaborative tags" : "Cerqueu o creeu etiquetes col·laboratives",
    "Collaborative tags …" : "Etiquetes col·laboratives…",
    "No tags to select, type to create a new tag" : "No hi ha cap etiqueta per seleccionar, escriviu per a crear una etiqueta nova",
    "Failed to load tags" : "No s'han pogut carregar les etiquetes",
    "Failed to load selected tags" : "No s'han pogut carregar les etiquetes seleccionades",
    "Failed to select tag" : "No s'ha pogut seleccionar l'etiqueta",
    "Failed to create tag" : "No s'ha pogut crear l'etiqueta",
    "Failed to delete tag" : "No s'ha pogut suprimir l'etiqueta",
    "This file has the tag {tag}" : "Aquest fitxer té l'etiqueta {tag}",
    "This file has the tags {firstTags} and {lastTag}" : "Aquest fitxer té les etiquetes {firstTags} i {lastTag}",
    "Failed to load last used tags" : "No s'han pogut carregar les etiquetes utilitzades recentment",
    "Missing \"Content-Location\" header" : "Falta la capçalera «Content-Location»",
    "Tagged files" : "Fitxers etiquetats",
    "Select tags to filter by" : "Seleccioneu les etiquetes que voleu filtrar",
    "No tags found" : "No s'ha trobat cap etiqueta",
    "Please select tags to filter by" : "Seleccioneu les etiquetes que voleu filtrar",
    "No files found for the selected tags" : "No s'ha trobat cap fitxer per a les etiquetes seleccionades",
    "Collaborative tags are available for all users. Restricted tags are visible to users but cannot be assigned by them. Invisible tags are for internal use, since users cannot see or assign them." : "Les etiquetes col·laboratives estan disponibles per a tots els usuaris. Els usuaris poden veure les etiquetes restringides, però no les poden assignar. Les etiquetes invisibles són per a ús intern, perquè els usuaris no poden ni veure-les ni assignar-les.",
    "Create a new tag" : "Crea una etiqueta nova",
    "Name" : "Nom",
    "Public" : "Públic",
    "Restricted" : "Restringit",
    "Invisible" : "Invisible",
    "Delete" : "Suprimeix",
    "Reset" : "Reinicialitza",
    "No files in here" : "No hi ha cap fitxer aquí",
    "No entries found in this folder" : "No s'ha trobat cap entrada en aquesta carpeta",
    "Size" : "Mida",
    "Modified" : "Data de modificació"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-26.0.7p0.tgz: nextcloud/apps/systemtags/l10n/ca.js <==
OC.L10N.register(
    "systemtags",
    {
    "Tag name is empty" : "El nom de l'etiqueta és buit",
    "Update" : "Actualitza",
    "Create" : "Crea",
    "Select tag …" : "Seleccioneu una etiqueta…",
    "System tag %1$s added by the system" : "El sistema ha afegit l'etiqueta del sistema %1$s",
    "Added system tag {systemtag}" : "S'ha afegit l'etiqueta del sistema {systemtag}",
    "Added system tag %1$s" : "S'ha afegit l'etiqueta del sistema %1$s",
    "%1$s added system tag %2$s" : "%1$s ha afegit l'etiqueta del sistema %2$s",
    "{actor} added system tag {systemtag}" : "{actor} ha afegit l'etiqueta del sistema {systemtag}",
    "System tag %1$s removed by the system" : "El sistema ha suprimit l'etiqueta del sistema %1$s",
    "Removed system tag {systemtag}" : "S'ha suprimit l'etiqueta del sistema {systemtag}",
    "Removed system tag %1$s" : "S'ha suprimit l'etiqueta del sistema %1$s",
    "%1$s removed system tag %2$s" : "%1$s ha suprimit l'etiqueta del sistema %2$s",
    "{actor} removed system tag {systemtag}" : "{actor} ha suprimit l'etiqueta del sistema {systemtag}",
    "You created system tag %1$s" : "Heu creat l'etiqueta del sistema %1$s",
    "You created system tag {systemtag}" : "Heu creat l'etiqueta del sistema {systemtag}",
    "%1$s created system tag %2$s" : "%1$s ha creat l'etiqueta del sistema %2$s",
    "{actor} created system tag {systemtag}" : "{actor} ha creat l'etiqueta del sistema {systemtag}",
    "You deleted system tag %1$s" : "Heu suprimit l'etiqueta del sistema %1$s",
    "You deleted system tag {systemtag}" : "Heu suprimit l'etiqueta del sistema {systemtag}",
    "%1$s deleted system tag %2$s" : "%1$s ha suprimit l'etiqueta del sistema %2$s",
    "{actor} deleted system tag {systemtag}" : "{actor} ha suprimit l'etiqueta del sistema {systemtag}",
    "You updated system tag %2$s to %1$s" : "Heu actualitzat l'etiqueta del sistema %2$s a %1$s",
    "You updated system tag {oldsystemtag} to {newsystemtag}" : "Heu actualitzat l'etiqueta del sistema {oldsystemtag} a {newsystemtag}",
    "%1$s updated system tag %3$s to %2$s" : "%1$s ha actualitzat l'etiqueta del sistema %3$s a %2$s",
    "{actor} updated system tag {oldsystemtag} to {newsystemtag}" : "{actor} ha actualitzat l'etiqueta del sistema {oldsystemtag} a {newsystemtag}",
    "System tag %2$s was added to %1$s by the system" : "El sistema ha afegit l'etiqueta del sistema %2$s a %1$s",
    "System tag {systemtag} was added to {file} by the system" : "El sistema ha afegit l'etiqueta del sistema {systemtag} a {file}",
    "You added system tag %2$s to %1$s" : "Heu afegit l'etiqueta del sistema %2$s a %1$s",
    "You added system tag {systemtag} to {file}" : "Heu afegit l'etiqueta del sistema {systemtag} a {file}",
    "%1$s added system tag %3$s to %2$s" : "%1$s ha afegit l'etiqueta del sistema %3$s a %2$s",
    "{actor} added system tag {systemtag} to {file}" : "{actor} ha afegit l'etiqueta del sistema {systemtag} a {file}",
    "System tag %2$s was removed from %1$s by the system" : "El sistema ha suprimit l'etiqueta del sistema %2$s de %1$s",
    "System tag {systemtag} was removed from {file} by the system" : "El sistema ha suprimit l'etiqueta del sistema {systemtag} de {file}",
    "You removed system tag %2$s from %1$s" : "Heu suprimit l'etiqueta del sistema %2$s de %1$s",
    "You removed system tag {systemtag} from {file}" : "Heu suprimit l'etiqueta del sistema {systemtag} de {file}",
    "%1$s removed system tag %3$s from %2$s" : "%1$s ha suprimit l'etiqueta del sistema %3$s de %2$s",
    "{actor} removed system tag {systemtag} from {file}" : "{actor} ha suprimit l'etiqueta del sistema {systemtag} de {file}",
    "%s (restricted)" : "%s (restringit)",
    "%s (invisible)" : "%s (invisible)",
    "<strong>System tags</strong> for a file have been modified" : "S'han modificat les <strong>etiquetes del sistema</strong> d'un fitxer",
    "Tags" : "Etiquetes",
    "All tagged %s …" : "Tots els elements amb l'etiqueta %s…",
    "tagged %s" : "amb l'etiqueta %s",
    "Collaborative tags" : "Etiquetes col·laboratives",
    "Collaborative tagging functionality which shares tags among users." : "Funcionalitat d'etiquetatge col·laboratiu que permet compartir etiquetes entre usuaris.",
    "Collaborative tagging functionality which shares tags among users. Great for teams.\n\t(If you are a provider with a multi-tenancy installation, it is advised to deactivate this app as tags are shared.)" : "Funcionalitat d'etiquetatge col·laboratiu que permet compartir etiquetes entre usuaris. Fantàstica per a equips.\n\t(Si sou un proveïdor amb una instància del Nextcloud per a diversos clients, s'aconsella inhabilitar aquesta aplicació perquè les etiquetes es comparteixen amb tothom.)",
    "Loading collaborative tags …" : "S'estan carregant les etiquetes col·laboratives…",
    "Search or create collaborative tags" : "Cerqueu o creeu etiquetes col·laboratives",
    "Collaborative tags …" : "Etiquetes col·laboratives…",
    "No tags to select, type to create a new tag" : "No hi ha cap etiqueta per seleccionar, escriviu per a crear una etiqueta nova",
    "Failed to load tags" : "No s'han pogut carregar les etiquetes",
    "Failed to load selected tags" : "No s'han pogut carregar les etiquetes seleccionades",
    "Failed to select tag" : "No s'ha pogut seleccionar l'etiqueta",
    "Failed to create tag" : "No s'ha pogut crear l'etiqueta",
    "Failed to delete tag" : "No s'ha pogut suprimir l'etiqueta",
    "This file has the tag {tag}" : "Aquest fitxer té l'etiqueta {tag}",
    "This file has the tags {firstTags} and {lastTag}" : "Aquest fitxer té les etiquetes {firstTags} i {lastTag}",
    "No tags found" : "No s'ha trobat cap etiqueta",
    "Failed to load last used tags" : "No s'han pogut carregar les etiquetes utilitzades recentment",
    "Missing \"Content-Location\" header" : "Falta la capçalera «Content-Location»",
    "Collaborative tags are available for all users. Restricted tags are visible to users but cannot be assigned by them. Invisible tags are for internal use, since users cannot see or assign them." : "Les etiquetes col·laboratives estan disponibles per a tots els usuaris. Els usuaris poden veure les etiquetes restringides, però no les poden assignar. Les etiquetes invisibles són per a ús intern, perquè els usuaris no poden ni veure-les ni assignar-les.",
    "Create a new tag" : "Crea una etiqueta nova",
    "Name" : "Nom",
    "Public" : "Públic",
    "Restricted" : "Restringit",
    "Invisible" : "Invisible",
    "Delete" : "Suprimeix",
    "Reset" : "Reinicialitza",
    "No files in here" : "No hi ha cap fitxer aquí",
    "No entries found in this folder" : "No s'ha trobat cap entrada en aquesta carpeta",
    "Size" : "Mida",
    "Modified" : "Data de modificació",
    "Tagged files" : "Fitxers etiquetats",
    "Select tags to filter by" : "Seleccioneu les etiquetes que voleu filtrar",
    "Please select tags to filter by" : "Seleccioneu les etiquetes que voleu filtrar",
    "No files found for the selected tags" : "No s'ha trobat cap fitxer per a les etiquetes seleccionades"
},
"nplurals=2; plural=(n != 1);");
